Crate jj_ryu

Crate jj_ryu 

jj-ryu - Stacked PRs for Jujutsu

This library provides the core functionality for managing stacked pull requests when using Jujutsu (jj) as your version control system. It supports both GitHub and GitLab.

Architecture

The library is designed to be interface-agnostic, allowing it to be used from:

  • CLI applications
  • TUI applications
  • Web servers / REST APIs
  • WebSocket servers

All I/O is async and state is passed explicitly (no globals).

Re-exports

pub use error::Error;
pub use error::Result;
pub use types::*;

Modules

auth
Authentication for GitHub and GitLab
error
Error types for jj-ryu
graph
Change graph building
platform
Platform services for GitHub and GitLab
repo
jj-lib workspace wrapper
submit
Three-phase submission engine
tracking
Bookmark tracking for explicit submission management.
types
Core types for jj-ryu