pub fn build_stack_comment_data(
plan: &SubmissionPlan,
bookmark_to_pr: &HashMap<String, PullRequest>,
) -> StackCommentDataExpand description
Build stack comment data from the plan and PRs
pub fn build_stack_comment_data(
plan: &SubmissionPlan,
bookmark_to_pr: &HashMap<String, PullRequest>,
) -> StackCommentDataBuild stack comment data from the plan and PRs