Module tracking

Module tracking 

Bookmark tracking for explicit submission management.

This module provides persistence for tracking which bookmarks should be submitted to the remote platform. It stores metadata in .jj/repo/ryu/.

Structs

CachedPr
A cached PR association.
PrCache
PR cache state.
TrackedBookmark
A bookmark that has been explicitly tracked for submission.
TrackingState
Persistent state of tracked bookmarks.

Constants

PR_CACHE_VERSION
Current version of the PR cache file format.
TRACKING_VERSION
Current version of the tracking file format.

Functions

load_pr_cache
Load PR cache from disk.
load_tracking
Load tracking state from disk.
pr_cache_path
Get path to the PR cache file.
save_pr_cache
Save PR cache to disk.
save_tracking
Save tracking state to disk.
tracking_path
Get path to the tracking state file.