Module types

Module types 

Core types for jj-ryu

Structs

Bookmark
A jj bookmark (branch reference)
BookmarkSegment
A segment of changes belonging to one or more bookmarks
BranchStack
A stack of bookmarks from trunk to a leaf
ChangeGraph
The complete change graph for a repository
GitRemote
A git remote
LogEntry
A commit/change entry from jj log
NarrowedBookmarkSegment
A segment narrowed to a single bookmark (after user selection)
PlatformConfig
Platform configuration
PrComment
A comment on a pull request
PullRequest
A pull request / merge request

Enums

Platform
Detected platform type