pub struct ChangeGraph {
pub bookmarks: HashMap<String, Bookmark>,
pub stack: Option<BranchStack>,
pub excluded_bookmark_count: usize,
}Expand description
The complete change graph for a repository
Represents the single linear stack from trunk to working copy. Only bookmarks between trunk and working copy are included.
Fields
bookmarks: HashMap<String, Bookmark>All bookmarks in the stack by name
stack: Option<BranchStack>The single stack from trunk to working copy (None if working copy is at trunk)
excluded_bookmark_count: usizeNumber of bookmarks excluded due to merge commits