Bookmark tracking for explicit submission management.
This module provides persistence for tracking which bookmarks should be
submitted to the remote platform. It stores metadata in .jj/repo/ryu/.
Structs
- Cached
Pr - A cached PR association.
- PrCache
- PR cache state.
- Tracked
Bookmark - A bookmark that has been explicitly tracked for submission.
- Tracking
State - Persistent state of tracked bookmarks.
Constants
- PR_
CACHE_ VERSION - Current version of the PR cache file format.
- TRACKING_
VERSION - Current version of the tracking file format.
Functions
- load_
pr_ cache - Load PR cache from disk.
- load_
tracking - Load tracking state from disk.
- pr_
cache_ path - Get path to the PR cache file.
- save_
pr_ cache - Save PR cache to disk.
- save_
tracking - Save tracking state to disk.
- tracking_
path - Get path to the tracking state file.