Core types for jj-ryu
Structs
- Bookmark
- A jj bookmark (branch reference)
- Bookmark
Segment - A segment of changes belonging to one or more bookmarks
- Branch
Stack - A stack of bookmarks from trunk to a leaf
- Change
Graph - The complete change graph for a repository
- GitRemote
- A git remote
- LogEntry
- A commit/change entry from jj log
- Narrowed
Bookmark Segment - A segment narrowed to a single bookmark (after user selection)
- Platform
Config - Platform configuration
- PrComment
- A comment on a pull request
- Pull
Request - A pull request / merge request
Enums
- Platform
- Detected platform type